Plugin: 'simple_plugin'
Author: 'simple_plugin'
Email: 'simple_plugin@plugin.com'

This is a sample readme file with the supported syntax, the content of this file should be write in markdown.

You can find an overview of the valid tags that can be used to write the content of this file on the following link:
https://guides.github.com/features/mastering-markdown/#syntax
